/// <reference types="node" />
import * as EventEmitter from 'events';
import * as Types from './types';
/**
 * Pipeline contruido sobre docker para su utilizacion
 * en diferentes proyectos.
 */
export declare class DockerPipeline extends EventEmitter {
    /**
     * Variable que almacena la conexion a docker.
     * @private
     */
    private docker;
    /**
     * Manejador de eventos de docker.
     * @private
     */
    private events;
    /**
     * Bus de comunicacion interna
     * @private
     */
    private bus;
    /**
     * Coleccion de volumenes que son creados, y seran
     * eliminados al finalizar el pipeline.
     * @private
     */
    private collVol;
    /**
     * Coleccion de contenedores creados, y que seran
     * eliminados al finalizar el pipeline.
     * @private
     */
    private collCont;
    /**
     * Constructor de clase.
     * @param socketPath Direccion de, socket de docker
     */
    constructor(socketPath?: string);
    /**
     * Metodo que inicia la ejecucion de un pipeline.
     * @param PipelConf Pipeline Configuracion
     */
    start(PipelConf: Types.Pipele): Promise<any>;
    /**
     * Metodo para realizar la ejecucion de un paso del pipeline
     * @param Step Paso a ejecutar
     */
    private executeStep;
    /**
     * Metodo para ejecutar task en un contenedor creado.
     * @param Container Contenedor en el que se ejecutara
     * @param Step Paso que tiene los task
     * @private
     */
    private executeTask;
    /**
     * Metodo para procesar los mensajes desde Docker
     * @param Message Mensaje enviado
     * @private
     */
    private processMessage;
    /**
     * Metodo que realiza la eliminacion de todos los elementos
     * creados durante el pipeline.
     * @private
     * @void
     */
    private prune;
}
